pub struct FontMask { /* private fields */ }Implementations
sourceimpl FontMask
impl FontMask
pub const FAMILY: FontMask = _
pub const STYLE: FontMask = _
pub const VARIANT: FontMask = _
pub const WEIGHT: FontMask = _
pub const STRETCH: FontMask = _
pub const SIZE: FontMask = _
pub const GRAVITY: FontMask = _
pub const VARIATIONS: FontMask = _
sourcepub fn from_bits(bits: u32) -> Option<FontMask>
pub fn from_bits(bits: u32) -> Option<FontMask>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FontMask
pub const fn from_bits_truncate(bits: u32) -> FontMask
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FontMask
pub const unsafe fn from_bits_unchecked(bits: u32) -> FontMask
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FontMask) -> bool
pub const fn intersects(&self, other: FontMask) -> bool
Returns true if there are flags common to both self and other.