Struct pango::FontsetSimpleClass
source · [−]#[repr(C)]pub struct FontsetSimpleClass(_);Trait Implementations
sourceimpl Deref for FontsetSimpleClass
impl Deref for FontsetSimpleClass
type Target = <Fontset as ObjectType>::RustClassType
type Target = <Fontset as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FontsetSimpleClass
impl DerefMut for FontsetSimpleClass
sourceimpl IsClassFor for FontsetSimpleClass
impl IsClassFor for FontsetSimpleClass
type Instance = FontsetSimple
type Instance = FontsetSimple
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FontsetSimpleClass
impl Sync for FontsetSimpleClass