pub struct GlyphItemIter<'item> { /* private fields */ }Expand description
offset` to get to the text of @glyph_item. The @start_index and @end_index values can directly index into @text. The @start_glyph, @end_glyph, @start_char, and @end_char values however are zero-based for the @glyph_item. For each cluster, the item pointed at by the start variables is included in the cluster while the one pointed at by end variables is not.
None of the members of a GlyphItemIter should be modified manually.
Implementations
Sourceimpl<'item> GlyphItemIter<'item>
impl<'item> GlyphItemIter<'item>
pub fn new_start( glyph_item: &'item GlyphItem, text: &str, ) -> Result<Self, BoolError>
pub fn new_end( glyph_item: &'item GlyphItem, text: &str, ) -> Result<Self, BoolError>
pub fn next_cluster(&mut self) -> bool
pub fn prev_cluster(&mut self) -> bool
pub fn glyph_item(&self) -> &'item GlyphItem
pub fn text(&self) -> &GStr
pub fn start_glyph(&self) -> i32
pub fn start_index(&self) -> i32
pub fn start_char(&self) -> i32
pub fn end_glyph(&self) -> i32
pub fn end_index(&self) -> i32
pub fn end_char(&self) -> i32